@@ -20,6 +20,7 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include <Python.h>
 #include "py_funcs.h"
 #include "power.h"
 #include "expairseq.h"
@@ -333,8 +334,7 @@ bool power::info(unsigned inf) const
 			       (basis.info(info_flags::real) && exponent.info(info_flags::integer) && exponent.info(info_flags::even));
 		case info_flags::real:
 			return ((basis.info(inf) and
-                                 (exponent.info(info_flags::integer) or
-                                 exponent.info(info_flags::positive))) or
+                                 (exponent.info(info_flags::integer))) or
                                 (basis.info(info_flags::positive) and
                                  exponent.info(inf)));
 		case info_flags::has_indices: {
@@ -587,16 +587,20 @@ ex power::eval(int level) const
 			const bool exponent_is_crational = exponent_is_rational || num_exponent.is_crational();
 			if (!basis_is_crational || !exponent_is_crational) {
 				// return a plain float
-				return (new numeric(num_basis.power(num_exponent)))->setflag(status_flags::dynallocated |
-				                                                               status_flags::evaluated |
-				                                                               status_flags::expanded);
+				ex e = num_basis.power(num_exponent);
+                                if (not is_exactly_a<numeric>(e))
+	                                return (new power(ebasis, eexponent))->setflag(status_flags::dynallocated |
+	                                               status_flags::evaluated);
+                                else
+        				return e;
 			}
 
 			if (exponent_is_rational) {
-				const numeric res = num_basis.power(num_exponent);
-				if (res.is_crational()) {
-					return res;
-				}
+                                ex e = num_basis.power(num_exponent);
+                                if (is_exactly_a<numeric>(e)
+                                                and ex_to<numeric>(e).is_crational()) {
+                                        return e;
+                                }
 			}
 			GINAC_ASSERT(!num_exponent->is_integer());  // has been handled by now
 
@@ -612,23 +616,16 @@ ex power::eval(int level) const
 				}
 				if (q.is_zero()) {  // the exponent was in the allowed range 0<(n/m)<1
 					if (num_basis.is_rational()) {
-						// call rational_power_parts
-						// for a^b return c,d such that a^b = c*d^b
-						PyObject* basis_py = num_basis.to_pyobject();
-						PyObject* exponent_py = num_exponent.to_pyobject();
-						PyObject* restuple = py_funcs.py_rational_power_parts(basis_py, exponent_py);
-						if(restuple == nullptr) {
-							throw(std::runtime_error("power::eval, error in rational_power_parts"));
-						}
-						PyObject *ppower = PyTuple_GetItem(restuple,0);
-						PyObject *newbasis = PyTuple_GetItem(restuple,1);
-						const bool ppower_equals_one = PyObject_IsTrue(PyTuple_GetItem(restuple, 2)) != 0;
+						bool ppower_equals_one; // = PyObject_IsTrue(PyTuple_GetItem(restuple, 2)) != 0;
+                                                numeric newbasis, ppower;
+                                                rational_power_parts(num_basis,
+                                                                num_exponent, 
+                                                                ppower, 
+                                                                newbasis, 
+                                                                ppower_equals_one);
 						ex result = (new power(newbasis,exponent))->setflag(status_flags::dynallocated | status_flags::evaluated);
 						if (not ppower_equals_one)
 							result = (new mul(result, ppower))->setflag(status_flags::dynallocated | status_flags::evaluated);
-						Py_DECREF(restuple);
-						Py_DECREF(basis_py);
-						Py_DECREF(exponent_py);
 						return result;
 					}
 					return this->hold();
@@ -694,7 +691,7 @@ ex power::eval(int level) const
                                         for (auto & elem : addp->seq)
                                                 elem.coeff = ex_to<numeric>(elem.coeff).div_dyn(icont);
 
-                                        const numeric c = icont.power(num_exponent);
+                                        const numeric c = icont.pow_intexp(num_exponent);
                                         if (likely(not c.is_one()))
                                                 return (new mul(power(*addp, num_exponent), c))->setflag(status_flags::dynallocated);
                                         else
@@ -1372,7 +1369,7 @@ ex power::expand_add(const add & a, long n, unsigned options) const
                         if (n == k)
                                 binomial_coefficient = *_num1_p;
                         else
-                                binomial_coefficient = binomial(numeric(n), numeric(k)) * pow(ex_to<numeric>(a.overall_coeff), numeric(n-k));
+                                binomial_coefficient = binomial(numeric(n), numeric(k)) * (ex_to<numeric>(a.overall_coeff)).power(n-k);
 		}
 
 		// Multinomial expansion of power(+(x,...,z;0),k)*c^(n-k):
